#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2021 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o errexit
set -o pipefail

ONAP_UMBRELLA_CHART="${WORKSPACE}/build/onap-oom/kubernetes/dist/packages/onap-*.tgz"
HELM_BIN="${WORKSPACE}/bin/helm"
IMAGES_LIST="${WORKSPACE}/images.txt"
ONAP_OOM_GIT_REVISION=$(cd "${WORKSPACE}/build/onap-oom" && git rev-parse --short HEAD)
export NORDIX_ARM_REPO="nordix-oom"
export ARTIFACT_ARM_FOLDER="oom"
export BUILD_IDENTIFIER="${ONAP_OOM_GIT_REVISION}"
export NORDIX_ARTIFACT_URL="${NORDIX_ARM_HTTPS_URL}/${NORDIX_ARM_REPO}/${ARTIFACT_ARM_FOLDER}/${BUILD_IDENTIFIER}"

# NOTE(cian): Leaving this commented out for the moment.
#echo "Info  : Pushing ONAP umbrella chart to Nordix Harbor"
#${HELM_BIN} push "${ONAP_UMBRELLA_CHART}" "${NORDIX_REGISTRY}"

export BUILD_ARTIFACTS="${ONAP_UMBRELLA_CHART} ${IMAGES_LIST}"
echo "Info  : Uploading ${BUILD_ARTIFACTS} to Nordix ARM ${NORDIX_ARM_REPO} repository"
for BUILD_ARTIFACT in $BUILD_ARTIFACTS; do
  echo "Info  : Generating checksums for $BUILD_ARTIFACT"
  ARTIFACT_MD5SUM=$(md5sum "${BUILD_ARTIFACT}" | cut -d' ' -f1)
  ARTIFACT_SHASUM=$(shasum "${BUILD_ARTIFACT}" | cut -d' ' -f1)
  ARTIFACT_SHA256SUM=$(sha256sum "${BUILD_ARTIFACT}" | cut -d' ' -f1)

  REMOTE_ARTIFACT=$(basename "${BUILD_ARTIFACT}")

  echo "Info  : Uploading ${BUILD_ARTIFACT} to Nordix Artifactory"
  curl -s -S \
      -H "X-JFrog-Art-Api:${NORDIX_ARM_TOKEN}" \
      -H "X-Checksum-MD5:${ARTIFACT_MD5SUM}" \
      -H "X-Checksum-Sha1:${ARTIFACT_SHASUM}" \
      -H "X-Checksum-Sha256:${ARTIFACT_SHA256SUM}" \
      -T "${BUILD_ARTIFACT}" \
      "${NORDIX_ARTIFACT_URL}/${REMOTE_ARTIFACT}"
  echo "Info  : Artifact ${BUILD_ARTIFACT} is available on ${NORDIX_ARTIFACT_URL}/${REMOTE_ARTIFACT}"
done

echo "Done!"

# vim: set ts=2 sw=2 expandtab:
